@@ -239,9 +239,6 @@ def check_args(args):
   if args.bench is None:
     print("finstats: please provide benchmark code. See 'finstats --help'")
     return False
-  if args.version is not None:
-    print("finstats: v{}".format(VERSION))
-    return False
   return True
   
 
@@ -283,6 +280,7 @@ def parse_args():
   parser.add_argument(
     '--version',
     '-v',
-    help="finstats version",
+    action='version',
+    version='%(prog)s {}'.format(VERSION)
   )
   return parser.parse_args()
\ No newline at end of file
